@@ -1,5 +1,5 @@
 
-from ..data.ls_dyna import DEForc, Elout, EloutObject, Glstat, Matsum, Nodout, RCForc, SBTout, Secforc, Disbout, \
+from ..data.ls_dyna import DEForc, Elout, EloutObject, Glstat, Matsum, Nodout, RCForc, SBTout, SlipringOut, Secforc, Disbout, \
                            PartDisbout, Abstat, AbstatCPM, JointForc, Sleout, RigidBody, BoundaryCondition
 from ..utils.constants import ObjectConstantsForData
 
@@ -22,6 +22,7 @@ class DataContainer:
     _joint_forc = None
     _volume = None
     _sbtout = None
+    _slipringout = None
     _matsum = None
     _glstat = None
     _disbout = None
@@ -57,6 +58,8 @@ class DataContainer:
             return DataContainer._joint_forc
         elif name == ObjectConstantsForData.SEAT_BELT:
             return DataContainer._sbtout
+        elif name == ObjectConstantsForData.SLIP_RING:
+            return DataContainer._slipringout
         elif name == ObjectConstantsForData.CONTACT:
             return DataContainer._rcforc
         elif name == ObjectConstantsForData.ENERGY_PART:
@@ -103,6 +106,7 @@ class DataContainer:
         DataContainer._part_disbout = PartDisbout(binout, logger, dynasaur_def)
         DataContainer._rcforc = RCForc(binout, logger, dynasaur_def)
         DataContainer._sbtout = SBTout(binout, logger, dynasaur_def)
+        DataContainer._slipringout = SlipringOut(binout, logger, dynasaur_def)
         DataContainer._matsum = Matsum(binout, logger, dynasaur_def)
         DataContainer._glstat = Glstat(binout, logger, dynasaur_def)
         DataContainer._abstat = Abstat(binout, logger, dynasaur_def)
