@@ -127,17 +127,6 @@ class DynasaurDefinitions:
         self._data_vis = {}
         self._units = Units()
 
-    def binout_type_data_type_container(self, binout_name):
-        """
-
-        Args:
-          binout_name: return:
-
-        Returns:
-
-        """
-        return DataTypeMapping.binary_identifier_2_dynasaur_identifier(binout_name) in self._dynasaur_data_type_container
-
     def get_param_dict_from_command(self, command):
         """
 
@@ -229,26 +218,29 @@ class DynasaurDefinitions:
             exit("Exiting, check your def file")
         return self._data_vis[key]
 
-    def get_ids_from_name(self, name, data_container, binout_data_type):
+    def get_object_ids_from_object_name(self, object_name, data_container_name):
         """get ids from given name
 
         Args:
-          name: param data_container:
-          binout_data_type: return dict(name):
-          data_container: 
+          object_name: param data_container:
+          data_container_name:
 
         Returns:
 
         """
-        dynasaur_data_type = DataTypeMapping.binary_identifier_2_dynasaur_identifier(data_container)
-        d = self._dynasaur_data_type_container[dynasaur_data_type]
 
-        if name not in d.keys() or len(d) == 0:
-            self._logger.emit(LOGConstants.ERROR[0], "\"" + name + "\" is not defined for " + plugin_name)
-            time.sleep(.5)
-            return []
+        dynasaur_data_types = DataTypeMapping.binary_identifier_2_dynasaur_identifier(data_container_name)
+        ret = []
+        for dynasaur_data_type in dynasaur_data_types:
+            d = self._dynasaur_data_type_container[dynasaur_data_type]
+            if object_name not in d.keys() or len(d) == 0:
+                continue
+            ret = d[object_name]
 
-        return d[name]
+        if len(ret) == 0:
+            self._logger.emit(LOGConstants.ERROR[0], "\"" + object_name + "\" is not defined for " + ", ".join(dynasaur_data_types))
+
+        return ret
 
     def get_defined_objects_containing_parts(self, part_ids):
         """get defined object containing parts
