@@ -98,18 +98,6 @@ class PartDisbout(BinoutData):
         """
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'disbout')
 
-    def get_channels_ids_object_name(self, object_name, plugin_name):
-        """:return: time array
-
-        Args:
-          object_name: 
-          plugin_name: 
-
-        Returns:
-
-        """
-        return self._dynasaur_definitions.get_ids_from_name(object_name, "disbout_part", plugin_name)
-
     def get_element_ids_from_part_ids(self, part_ids):
         """
 
@@ -149,7 +137,7 @@ class PartDisbout(BinoutData):
 
         """
 
-        part_ids = self.get_channels_ids_object_name(ID, self._name)
+        part_ids = self._dynasaur_definitions.get_object_ids_from_object_name(ID, self._name)
         part_ids_to_element_ids = self.get_element_ids_from_part_ids(part_ids)
 
         assert (len(part_ids_to_element_ids) != 0)
@@ -1523,52 +1511,35 @@ class RCForc(BinoutData):
         """
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, "rcforc")
 
-    def get_measurement_channel(self, id_, channel_name):
+    def __init_data__(self, subdatatypes=[]):
+        """
+        initialize members:
+            * self._time
+            * self._time_interp
+            * self._ids
+
+        :param subdatatypes: subdatatypes to access data in lasso.dyna.Binout
+        :type subdatatypes:  list identifiers i.e. ["bndout", "velocity", "rigidbody"]]
+        :returns: None
+        :rtype: None
         """
 
-        Args:
-          id: param channel_name:
-          id_: 
-          channel_name: 
+        assert self._ids is None and self._time is None and self._time_interp is None
 
-        Returns:
+        self._time = self._binout.read(*subdatatypes, 'time').flatten() * self._dynasaur_definitions.get_units().time
+        self._time_interp = self._interp_time(self._time)
+        # TODO: Check if data is not there index out of range -> resulting crash
+        self._ids = np.array(self._binout.read(*subdatatypes, self.__class__.ids_name))
 
-        """
+        # ids converted to m and s ... "m" and "s" [1000, 1000] --> ["1000m", "1000s"]
+        if isinstance(self._binout, lasso.dyna.Binout):
+            self._ids = np.array([str(i) + "s" if nr % 2 else str(i) + "m" for nr, i in enumerate(self._ids)])
+        if len(self._ids.shape) > 1:
+            self._ids = self._ids[0]
 
-        if not isinstance(self._binout, lasso.dyna.Binout):
-            # call implementation
-            # used for madymo implementation
-            # maybe changed
-            return BinoutData.get_measurement_channel(self, id_, channel_name)
+        self._read_data_channels(subdatatypes=subdatatypes)
 
-        unit = self._get_unit_dimension_from_channel_name(channel_name)
-
-        if channel_name == 'time':
-            return self._time.reshape(-1, 1)
-
-        # split id into number and master slave indicator
-        id_nr = int(id_[:-1])
-        id_slave_master = id_[-1]
-
-        assert (id_slave_master == 's' or id_slave_master == 'm')
-
-        id_slave_master = 0 if id_slave_master == 's' else 1
-        data_index = np.where(int(id_nr) == self._ids)[0]
-
-        if len(data_index) == 0:
-            self._logger.emit(LOGConstants.ERROR[0], 'ID ' + str(id_nr) + ' not in binout')
-            return []
-        data_index = [data_index[id_slave_master]]
-
-        self._logger.emit(LOGConstants.DATA_PLUGIN[0], 'read id ' + str(id_) + ' from channel name: ' + channel_name)
-        assert (len(data_index) >= 1)
-
-        if channel_name not in self._data.keys():
-            self._logger.emit(LOGConstants.ERROR[0], str(id_) + ' has no data with the identifier : ' + channel_name)
-            return []
-
-        d = self._data[channel_name][:, data_index]
-        return d.reshape(-1, len(data_index)) * unit
+        assert len(self._ids.shape) == 1
 
 
 class SBTout(BinoutData):
@@ -1589,6 +1560,25 @@ class SBTout(BinoutData):
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, "sbtout")
 
 
+class SlipringOut(BinoutData):
+    """ """
+    DATA_CHANNEL_TYPES = ['ring_slip']
+    ids_name = "slipring_ids"
+
+    def __init__(self, binout, logger, dynasaur_definitions):
+        """
+        Initialization/constructor
+
+        :param: binout
+        :param: logger
+        :param: dynasaur definition
+
+        :return:
+        """
+        BinoutData.__init__(self, binout, logger, dynasaur_definitions, "sbtout")
+
+
+
 class Secforc(BinoutData):
     """ """
     DATA_CHANNEL_TYPES = ['x_force', 'y_force', 'z_force', 'x_moment', 'y_moment', 'z_moment',
