@@ -30,6 +30,27 @@ class MadymoData:
             else:
                 assert False
 
+    def _extract_outlet_data(self, node, data_type="sbtout"):
+
+        # extract matching ids
+        id_strings = [(signal, ''.join([chr(i) for i in list(node[signal].attrs.items())[0][1] if i != 0]).strip())
+                      for signal in node.keys() if signal.startswith("SIGNAL")]
+
+        print(id_strings)
+
+        sig_id_dir = [(signal, *self._get_simplified_fem_node_id(id_)) for signal, id_ in id_strings]
+
+        for sig, id_, dir_ in sig_id_dir:
+            id_idx = self._d[data_type]["slipring_ids"].index(id_)
+            if dir_[0] == "x":
+                self._d[data_type][DataChannelTypesNodout.X_COORDINATE][:, id_idx] = node[sig]["Y_VALUES"][0, :]
+            elif dir_[0] == "y":
+                self._d[data_type][DataChannelTypesNodout.Y_COORDINATE][:, id_idx] = node[sig]["Y_VALUES"][0, :]
+            elif dir_[0] == "z":
+                self._d[data_type][DataChannelTypesNodout.Z_COORDINATE][:, id_idx] = node[sig]["Y_VALUES"][0, :]
+            else:
+                assert False
+
     def _extratct_data(self, node, data_type, channel_type, idx_madymo_data, ids_name=None):
         """
 
@@ -56,7 +77,7 @@ class MadymoData:
                 if id_to_compare == id_:
                     self._d[data_type][channel_type][:, idx] = node[key]["Y_VALUES"][idx_madymo_data, :]
 
-    def _extract_data_energy(self, node, data_type, ids,  enegry_type):
+    def _extract_data_energy(self, node, data_type, ids, enegry_type):
         """
 
         Args:
@@ -316,7 +337,7 @@ class MadymoData:
                             data_type == DataChannelTypesNodout.Z_ACCELERATION:
                         idx_madymo_data = 1 if data_type == DataChannelTypesNodout.X_ACCELERATION else (
                             2 if data_type == DataChannelTypesNodout.Y_ACCELERATION else 3)
-                        self._extratct_data(f["MODEL_0/Linear accelerations"],"nodout",
+                        self._extratct_data(f["MODEL_0/Linear accelerations"], "nodout",
                                             data_type, idx_madymo_data=idx_madymo_data)
 
                     elif data_type == DataChannelTypesNodout.X_VELOCITY or \
@@ -342,9 +363,9 @@ class MadymoData:
                             2 if data_type == DataChannelTypesNodout.Y_DISPLACEMENT else 3)
                         self._extratct_data(f["MODEL_0/Linear displacements"], "nodout", data_type,
                                             idx_madymo_data=idx_madymo_data)
-                        #self._extratct_data(f["/MODEL_0/Relative displacements"], "nodout", data_type,
+                        # self._extratct_data(f["/MODEL_0/Relative displacements"], "nodout", data_type,
                         #                    idx_madymo_data=idx_madymo_data)
-                        #self._extratct_data(f["/MODEL_0/Retractor | pretensioner | load limiter | tying"], "nodout", data_type,
+                        # self._extratct_data(f["/MODEL_0/Retractor | pretensioner | load limiter | tying"], "nodout", data_type,
                         #                    idx_madymo_data=idx_madymo_data)
 
                 if "FEM node time-history output" in f["MODEL_0"].keys():
@@ -389,14 +410,16 @@ class MadymoData:
                 for data_type in data_types_to_be_filled:
                     self._d['sbtout'][data_type] = np.empty(dimension)
                     self._d['sbtout'][data_type][:] = np.nan
-                    self._extratct_data(f["MODEL_0/Relative displacements"], "sbtout", data_type, idx_madymo_data=0,
-                                        ids_name="slipring_ids")
+
+                self._extract_outlet_data(f["MODEL_0/Retractor | pretensioner | load limiter | tying"],
+                                          data_type="sbtout")
+                #self._extratct_data(f["MODEL_0/Retractor | pretensioner | load limiter | tying"], "sbtout",
+                #                        data_type, idx_madymo_data=0, ids_name="slipring_ids")
                 # TODO
 
-
-                dimension = (self._d['sbtout']['time'].shape[0], len(self._d['sbtout']['belt_ids']))
-                data_types_to_be_filled = ["belt_force", "belt_length"]# i for i in self._d['sbtout'].keys() if i != "ids" and i != "time" and i != "legend_ids"]
-                print(data_types_to_be_filled)
+                #dimension = (self._d['sbtout']['time'].shape[0], len(self._d['sbtout']['belt_ids']))
+                #data_types_to_be_filled = ["belt_force", "belt_length"]# i for i in self._d['sbtout'].keys() if i != "ids" and i != "time" and i != "legend_ids"]
+                #print(data_types_to_be_filled)
                 # TODO
 
 
@@ -481,15 +504,10 @@ class MadymoData:
                         self._d['secforc'] = {"ids": [], "legend_ids": [], "time": None}
 
                 if 'sbtout' not in self._d.keys():
-                    if node.parent.name.split("/")[-1].startswith("Relative displacements"):
+                    if node.parent.name.split("/")[-1].startswith('Retractor | pretensioner | load limiter | tying'):
                         self._d['sbtout'] = {"belt_ids": [], "slipring_ids": [], "legend_ids": [], "time": None}
 
                 if node.parent.name.split("/")[-1].startswith("Energy output"):
-                    # TODO
-                    # self._d['glstat'][DataChannelTypesNodout.RX_ACCELERATION] = None
-                    # self._d['glstat'][DataChannelTypesNodout.RY_ACCELERATION] = None
-                    # self._d['glstat'][DataChannelTypesNodout.RZ_ACCELERATION] = None
-
                     self._add_energy_ids(node.parent, data_type="glstat")
                     self._add_time(node.parent, data_type="glstat")
                     self._add_time(node.parent, data_type="matsum")
@@ -564,7 +582,7 @@ class MadymoData:
                     self._add_ids(node.parent, data_type="secforc")
                     self._add_time(node.parent, data_type="secforc")
 
-                elif node.parent.name.split("/")[-1].startswith("Relative displacements"):
+                elif node.parent.name.split("/")[-1].startswith("Retractor | pretensioner | load limiter | tying"):
                     self._d["sbtout"][DataChannelTypesSbtout.RING_SLIP] = None
                     self._add_ids(node.parent, data_type="sbtout", sbtout="slipring")
                     self._add_time(node.parent, data_type="sbtout")
