@@ -149,6 +149,7 @@ class ObjectConstantsForData:
     NODE = "NODE"
     JOINT = "JOINT"
     SEAT_BELT = "SEAT_BELT"
+    SLIP_RING = "SLIP_RING"
     CONTACT = "CONTACT"
     ENERGY_PART = "ENERGY_PART"
     ENERGY_GLOBAL = "ENERGY_GLOBAL"
@@ -162,22 +163,22 @@ class ObjectConstantsForData:
 class DataTypeMapping:
     """ """
     mapping = [(ObjectConstantsForData.ELEMENT, "elout"),
-                (ObjectConstantsForData.AIRBAG, "abstat"),
-                (ObjectConstantsForData.AIRBAG_CPM, "abstat_cpm"),
-                (ObjectConstantsForData.CROSS_SECTION, "secforc"),
-                (ObjectConstantsForData.NODE, "nodout"),
-                (ObjectConstantsForData.JOINT, "jntforc"),
-                (ObjectConstantsForData.SEAT_BELT, "sbtout"),
-                (ObjectConstantsForData.CONTACT, "rcforc"),
-                (ObjectConstantsForData.DISCRETE, "deforc"),
-                (ObjectConstantsForData.ENERGY_PART, "matsum"),
-                (ObjectConstantsForData.ENERGY_GLOBAL, "glstat"),
-                (ObjectConstantsForData.DISBOUT, "disbout"),
-                (ObjectConstantsForData.DISBOUT_PART, "disbout_part"),
-                (ObjectConstantsForData.SLEOUT, "sleout"),
-                (ObjectConstantsForData.RIGID_BODY, "rbdout"),
-                (ObjectConstantsForData.BOUNDARY_CONDITION, "bndout"),
-                ]
+               (ObjectConstantsForData.AIRBAG, "abstat"),
+               (ObjectConstantsForData.AIRBAG_CPM, "abstat_cpm"),
+               (ObjectConstantsForData.CROSS_SECTION, "secforc"),
+               (ObjectConstantsForData.NODE, "nodout"),
+               (ObjectConstantsForData.JOINT, "jntforc"),
+               (ObjectConstantsForData.SEAT_BELT, "sbtout"),
+               (ObjectConstantsForData.SLIP_RING, "sbtout"),
+               (ObjectConstantsForData.CONTACT, "rcforc"),
+               (ObjectConstantsForData.DISCRETE, "deforc"),
+               (ObjectConstantsForData.ENERGY_PART, "matsum"),
+               (ObjectConstantsForData.ENERGY_GLOBAL, "glstat"),
+               (ObjectConstantsForData.DISBOUT, "disbout"),
+               (ObjectConstantsForData.DISBOUT_PART, "disbout_part"),
+               (ObjectConstantsForData.SLEOUT, "sleout"),
+               (ObjectConstantsForData.RIGID_BODY, "rbdout"),
+               (ObjectConstantsForData.BOUNDARY_CONDITION, "bndout")]
 
     @staticmethod
     def binary_identifier_2_dynasaur_identifier(binary_data_type):
@@ -190,12 +191,12 @@ class DataTypeMapping:
 
         """
 
+        possible_container = []
         for tpl in DataTypeMapping.mapping:
             if tpl[1] == binary_data_type:
-                return tpl[0]
-
-        return None
+                possible_container.append(tpl[0])
 
+        return None if len(possible_container) == 0 else possible_container
 
     @staticmethod
     def dynasaur_identifier_2_binary_identifier(dynasaur_data_type):
@@ -213,8 +214,6 @@ class DataTypeMapping:
 
         return None
 
-
-
 class JsonConstants:
     """ """
     TYPE = "type"
@@ -466,3 +465,4 @@ class DataChannelTypesSbtout:
     """ """
     BELT_FORCE = "belt_force"
     BELT_LENGTH = "belt_length"
+    RING_SLIP = "ring_slip"
