@@ -5,19 +5,18 @@ import colorama
 
 class ConsoleLogger(object):
     def __init__(self):
-        """
-        Initialization constructor WidgetLogger
-        :param:
-        :return:
-        """
+        """Initialization constructor WidgetLogger"""
         colorama.init()
         pass
 
     def _get_color_for_label(self, label):
-        """
-        Get color from given label
-        :param: label
-        :return:
+        """Get color from given label
+
+        Args:
+          label: 
+
+        Returns:
+
         """
         log_attributes = [a for a in dir(LOGConstants) if not a.startswith("__")]
         attribute_values = [[LOGConstants.__dict__[key]] for key in LOGConstants.__dict__.keys() if
@@ -26,11 +25,14 @@ class ConsoleLogger(object):
         return color
 
     def emit(self, label, record):
-        """
-        emit/print the message
-        :param: label
-        :param: record
-        :return:
+        """emit/print the message
+
+        Args:
+          label: 
+          record: 
+
+        Returns:
+
         """
         color = self._get_color_for_label(label)
         print(colored(label, color) + "\t" + record)
